@@ -1,16 +1,31 @@
 import readline
 import mdpeditor.mdpblocks.provide
+import mdpeditor.mdpblocks.process
 import mdpeditor.compile
 import mdpeditor.explain
 import mdpeditor.parameterhelp.extract
+import time
 
 
-class VolcabCompleter:
-    def __init__(self, volcab):
-        self.volcab = volcab
+class Completer:
+    def __init__(self, blocks, parameter_keys):
+        self.blocks = blocks
+        self.parameter_keys = parameter_keys
 
-    def complete(self, text, state):
-        results = [x + " " for x in self.volcab if x.startswith(text)] + [None]
+    def complete_compile(self, text, state):
+        """ add a = for parameters tab completion
+        """
+        results = [
+            x + " " for x in self.blocks if x.startswith(text)] + [
+            x + "=" for x in self.parameter_keys if x.startswith(text)
+        ] + [None]
+        return results[state]
+
+    def complete_explain(self, text, state):
+        results = [
+            x + " " for x in self.blocks if x.startswith(text)] + [
+            x + " " for x in self.parameter_keys if x.startswith(text)
+        ] + [None]
         return results[state]
 
 
@@ -24,7 +39,8 @@ def console_prompt_string(compile_mode):
                              f"{modes[0]}" + " mode.\n")
     console_prompt_string += (
         "Press [bold][TAB][/bold] to list input options.\n")
-    console_prompt_string += ("Press [bold][CTRL]+C[/bold] to exit.\n")
+    console_prompt_string += ("Press [bold][CTRL]+C[/bold] to exit, type "
+                              "[bold]help[/] for more details on usage.")
 
     console_prompt_string += f"\n> [bold]{modes[1]}[/] "
 
@@ -36,7 +52,6 @@ def console_prompt_string(compile_mode):
 
 def run_interactive_prompt(console, version):
 
-    error_style = "bold color(1)"
     simple_text_style = "color(6)"
 
     # introductory message
@@ -46,22 +61,9 @@ def run_interactive_prompt(console, version):
         "\n\nHere you"
         " can learn about .mdp parameters and parameter blocks "
         "and test different parameter combinations.\n\nFor production"
-        " code in workflows, use the command line options as shown"
-        " when running [italic]mdpeditor --help.\n",
-        style=simple_text_style)
-    available_blocks = mdpeditor.mdpblocks.provide.available_parameter_blocks()
-    console.print("To help you compile your .mdp file, you can currently "
-                  "choose from these blocks:\n\n[bold]" +
-                  "\n".join(available_blocks),
-                  style=simple_text_style)
-    console.print(
-        "\nLearn more about these blocks with the [bold]explain[/] mode.\n",
-        style=simple_text_style)
-
-    console.print(
-        "\nA typical input is \n"
-        "[italic]compile --merge-duplicates force_field.amber "
-        "pressure.atomspheric[/]\n",
+        " code in workflows, copy paste the prompt below like [bold]"
+        "mdpeditor compile ... [/]"
+        " and have a look at [bold]mdpeditor --help[/].\n",
         style=simple_text_style)
 
     # set up tab completion
@@ -69,8 +71,10 @@ def run_interactive_prompt(console, version):
     readline.set_completer_delims(" ")
     blocks = mdpeditor.mdpblocks.provide.available_parameter_blocks()
     mdp_options = mdpeditor.parameterhelp.extract.mdp_options_list()
-    completer = VolcabCompleter(blocks + mdp_options)
-    readline.set_completer(completer.complete)
+    completer = Completer(
+        blocks,
+        mdp_options + mdpeditor.mdpblocks.process.tab_completion_hints())
+    readline.set_completer(completer.complete_compile)
 
     merge_right = True
     full_mdp = False
@@ -78,24 +82,27 @@ def run_interactive_prompt(console, version):
     line = ""
     compile_mode = False
     while line is not None or line == "end":
-
         # swap mode if only [Enter] was pressed
+        # alter tab completion
         if line == "":
             compile_mode = not compile_mode
+            if compile_mode:
+                readline.set_completer(completer.complete_compile)
+            else:
+                readline.set_completer(completer.complete_explain)
 
         try:
             console.rule(style="")
             line = console.input(console_prompt_string(compile_mode))
+            if line == "":
+                continue
             if compile_mode:
-                if line == "":
-                    continue
                 output = mdpeditor.compile.run_compile(line.split(),
                                                        merge_right, full_mdp)
-                console.print(output)
             else:
-                if line == "":
-                    continue
-                mdpeditor.explain.run_explain(console, line)
+                output = mdpeditor.explain.run_explain(line)
+            console.rule()
+            console.print(output)
 
         # end gracefully when the user interrupts
         except KeyboardInterrupt:
@@ -104,14 +111,14 @@ def run_interactive_prompt(console, version):
             line = None
         # do not exit like we do when running pure command line mode
         except SystemExit as e:
-            console.print("Error: " + e.__str__() + "\n", style=error_style)
+            console.print(e.__str__() + "\n", style=simple_text_style)
 
     console.print("\n\nThanks for using mdpeditor!")
 
     console.print(
         "\nDiscuss .mdp parameters at "
-        "https://gromacs.bioexcel.eu/tag/mdp-parameters", justify="right"
-    )
+        "https://gromacs.bioexcel.eu/tag/mdp-parameters",
+        justify="right")
 
     console.print(
         "Report issues and suggestions for mdpeditor at "
